%%
%% %CopyrightBegin%
%%
%% Copyright Ericsson AB 2017. All Rights Reserved.
%%
%% Licensed under the Apache License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License.
%% You may obtain a copy of the License at
%%
%%     http://www.apache.org/licenses/LICENSE-2.0
%%
%% Unless required by applicable law or agreed to in writing, software
%% distributed under the License is distributed on an "AS IS" BASIS,
%% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
%% See the License for the specific language governing permissions and
%% limitations under the License.
%%
%% %CopyrightEnd%
%%

%%
%% Internal definitions for the 'file' module and friends.
%%

-ifndef(FILE_INTERNAL_HRL_).
-define(FILE_INTERNAL_HRL_, 1).

-include("file.hrl").

-define(CALL_FD(Fd, Method, Args),
    apply(Fd#file_descriptor.module, Method, [Fd | Args])).

-endif.
